@@ -180,8 +180,8 @@ class Getsms(object):
                     code = '500'
                 infos.append({
                         'date': row.create_date,
-                        'submit_date': row.submit_date.strip(),
-                        'done_date': row.done_date.strip(),
+                        'submit_date': row.submit_date,
+                        'done_date': row.done_date,
                         'status': row.status,
                         'code': code,
                         'msisdn_dest': row.msisdn,
